from setuptools import setup, find_packages

setup(name="says-hello", version="0.0.15", description="Returns 'Hello world'", author="Me", packages=find_packages(),
      keywords=["hello", "python", "say"], long_description="Returns 'Hello world'", classifiers=[
            "Development Status :: 1 - Planning",
            "Programming Language :: Python :: 3",
            "Operating System :: Unix",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows",
    ]
)
